# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


EVT_INT = object
IntCtrl = object
IntUpdatedEvent = object
IntValidator = object
LONGTYPE = object
MAXSIZE = 0
MINSIZE = 0
WXK_CTRL_V = 0
WXK_CTRL_X = 0
wxEVT_COMMAND_INT_UPDATED = 0



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


BuildLanguageCountryMapping = dummy_function
CreateLanguagesResourceLists = dummy_function
GetLanguageFlag = dummy_function
GetWxIdentifierForLanguage = dummy_function
LC_ALL = 0
LC_AVAILABLE = 0
LC_ONLY = 0
LanguageListCtrl = object
_l = ''
_wxLangIds = []
langIdCountryMap = dict()



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


AbortEvent = object
AbortedException = object
DelayedResult = object
Handler = object
PreProcessChain = object
Producer = object
Sender = object
SenderCallAfter = object
SenderNoWx = object
SenderWxEvent = object
Struct = object
startWorker = dummy_function



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


EVT_MEDIA_FINISHED = object
EVT_MEDIA_LOADED = object
EVT_MEDIA_PAUSE = object
EVT_MEDIA_PLAY = object
EVT_MEDIA_STATECHANGED = object
EVT_MEDIA_STOP = object
MEDIABACKEND_DIRECTSHOW = ''
MEDIABACKEND_GSTREAMER = ''
MEDIABACKEND_MCI = ''
MEDIABACKEND_QUICKTIME = ''
MEDIABACKEND_REALPLAYER = ''
MEDIABACKEND_WMP10 = ''
MEDIACTRLPLAYERCONTROLS_DEFAULT = object
MEDIACTRLPLAYERCONTROLS_NONE = object
MEDIACTRLPLAYERCONTROLS_STEP = object
MEDIACTRLPLAYERCONTROLS_VOLUME = object
MEDIASTATE_PAUSED = object
MEDIASTATE_PLAYING = object
MEDIASTATE_STOPPED = object
MediaCtrl = object
MediaCtrlPlayerControls = object
MediaEvent = object
MediaState = object
USE_MEDIACTRL = 0
wxEVT_MEDIA_FINISHED = 0
wxEVT_MEDIA_LOADED = 0
wxEVT_MEDIA_PAUSE = 0
wxEVT_MEDIA_PLAY = 0
wxEVT_MEDIA_STATECHANGED = 0
wxEVT_MEDIA_STOP = 0



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


DATAVIEW_CELL_ACTIVATABLE = object
DATAVIEW_CELL_EDITABLE = object
DATAVIEW_CELL_FOCUSED = object
DATAVIEW_CELL_INERT = object
DATAVIEW_CELL_INSENSITIVE = object
DATAVIEW_CELL_PRELIT = object
DATAVIEW_CELL_SELECTED = object
DATAVIEW_COL_HIDDEN = object
DATAVIEW_COL_REORDERABLE = object
DATAVIEW_COL_RESIZABLE = object
DATAVIEW_COL_SORTABLE = object
DVC_DEFAULT_MINWIDTH = 0
DVC_DEFAULT_RENDERER_SIZE = 0
DVC_DEFAULT_WIDTH = 0
DVC_TOGGLE_DEFAULT_WIDTH = 0
DVR_DEFAULT_ALIGNMENT = 0
DV_HORIZ_RULES = 0
DV_MULTIPLE = 0
DV_NO_HEADER = 0
DV_ROW_LINES = 0
DV_SINGLE = 0
DV_VARIABLE_LINE_HEIGHT = 0
DV_VERT_RULES = 0
DataViewBitmapRenderer = object
DataViewCellMode = object
DataViewCellRenderState = object
DataViewChoiceRenderer = object
DataViewColumn = object
DataViewColumnFlags = object
DataViewCtrl = object
DataViewCtrlNameStr = bytes()
DataViewCustomRenderer = object
DataViewDateRenderer = object
DataViewEvent = object
DataViewIconText = object
DataViewIconTextRenderer = object
DataViewIndexListModel = object
DataViewItem = object
DataViewItemArray = object
DataViewItemAttr = object
DataViewItemObjectMapper = object
DataViewListCtrl = object
DataViewListModel = object
DataViewListStore = object
DataViewModel = object
DataViewModelNotifier = object
DataViewProgressRenderer = object
DataViewRenderer = object
DataViewSpinRenderer = object
DataViewTextRenderer = object
DataViewToggleRenderer = object
DataViewTreeCtrl = object
DataViewTreeStore = object
DataViewVirtualListModel = object
EVT_DATAVIEW_CACHE_HINT = object
EVT_DATAVIEW_COLUMN_HEADER_CLICK = object
EVT_DATAVIEW_COLUMN_HEADER_RIGHT_CLICK = object
EVT_DATAVIEW_COLUMN_REORDERED = object
EVT_DATAVIEW_COLUMN_SORTED = object
EVT_DATAVIEW_ITEM_ACTIVATED = object
EVT_DATAVIEW_ITEM_BEGIN_DRAG = object
EVT_DATAVIEW_ITEM_COLLAPSED = object
EVT_DATAVIEW_ITEM_COLLAPSING = object
EVT_DATAVIEW_ITEM_CONTEXT_MENU = object
EVT_DATAVIEW_ITEM_DROP = object
EVT_DATAVIEW_ITEM_DROP_POSSIBLE = object
EVT_DATAVIEW_ITEM_EDITING_DONE = object
EVT_DATAVIEW_ITEM_EDITING_STARTED = object
EVT_DATAVIEW_ITEM_EXPANDED = object
EVT_DATAVIEW_ITEM_EXPANDING = object
EVT_DATAVIEW_ITEM_START_EDITING = object
EVT_DATAVIEW_ITEM_VALUE_CHANGED = object
EVT_DATAVIEW_SELECTION_CHANGED = object
EVT_TREELIST_COLUMN_SORTED = object
EVT_TREELIST_ITEM_ACTIVATED = object
EVT_TREELIST_ITEM_CHECKED = object
EVT_TREELIST_ITEM_CONTEXT_MENU = object
EVT_TREELIST_ITEM_EXPANDED = object
EVT_TREELIST_ITEM_EXPANDING = object
EVT_TREELIST_SELECTION_CHANGED = object
NullDataViewItem = object
PyDataViewCustomRenderer = object
PyDataViewIndexListModel = object
PyDataViewModel = object
PyDataViewVirtualListModel = object
TLI_FIRST = object
TLI_LAST = object
TL_3STATE = 0
TL_CHECKBOX = 0
TL_DEFAULT_STYLE = 0
TL_MULTIPLE = 0
TL_NO_HEADER = 0
TL_SINGLE = 0
TL_STYLE_MASK = 0
TL_USER_3STATE = 0
TreeListCtrl = object
TreeListCtrlNameStr = bytes()
TreeListEvent = object
TreeListItem = object
TreeListItemComparator = object
wxEVT_COMMAND_DATAVIEW_CACHE_HINT = 0
wxEVT_COMMAND_DATAVIEW_COLUMN_HEADER_CLICK = 0
wxEVT_COMMAND_DATAVIEW_COLUMN_HEADER_RIGHT_CLICK = 0
wxEVT_COMMAND_DATAVIEW_COLUMN_REORDERED = 0
wxEVT_COMMAND_DATAVIEW_COLUMN_SORTED = 0
wxEVT_COMMAND_DATAVIEW_ITEM_ACTIVATED = 0
wxEVT_COMMAND_DATAVIEW_ITEM_BEGIN_DRAG = 0
wxEVT_COMMAND_DATAVIEW_ITEM_COLLAPSED = 0
wxEVT_COMMAND_DATAVIEW_ITEM_COLLAPSING = 0
wxEVT_COMMAND_DATAVIEW_ITEM_CONTEXT_MENU = 0
wxEVT_COMMAND_DATAVIEW_ITEM_DROP = 0
wxEVT_COMMAND_DATAVIEW_ITEM_DROP_POSSIBLE = 0
wxEVT_COMMAND_DATAVIEW_ITEM_EDITING_DONE = 0
wxEVT_COMMAND_DATAVIEW_ITEM_EDITING_STARTED = 0
wxEVT_COMMAND_DATAVIEW_ITEM_EXPANDED = 0
wxEVT_COMMAND_DATAVIEW_ITEM_EXPANDING = 0
wxEVT_COMMAND_DATAVIEW_ITEM_START_EDITING = 0
wxEVT_COMMAND_DATAVIEW_ITEM_VALUE_CHANGED = 0
wxEVT_COMMAND_DATAVIEW_SELECTION_CHANGED = 0
wxEVT_COMMAND_TREELIST_COLUMN_SORTED = 0
wxEVT_COMMAND_TREELIST_ITEM_ACTIVATED = 0
wxEVT_COMMAND_TREELIST_ITEM_CHECKED = 0
wxEVT_COMMAND_TREELIST_ITEM_CONTEXT_MENU = 0
wxEVT_COMMAND_TREELIST_ITEM_EXPANDED = 0
wxEVT_COMMAND_TREELIST_ITEM_EXPANDING = 0
wxEVT_COMMAND_TREELIST_SELECTION_CHANGED = 0
wxEVT_DATAVIEW_CACHE_HINT = 0
wxEVT_DATAVIEW_COLUMN_HEADER_CLICK = 0
wxEVT_DATAVIEW_COLUMN_HEADER_RIGHT_CLICK = 0
wxEVT_DATAVIEW_COLUMN_REORDERED = 0
wxEVT_DATAVIEW_COLUMN_SORTED = 0
wxEVT_DATAVIEW_ITEM_ACTIVATED = 0
wxEVT_DATAVIEW_ITEM_BEGIN_DRAG = 0
wxEVT_DATAVIEW_ITEM_COLLAPSED = 0
wxEVT_DATAVIEW_ITEM_COLLAPSING = 0
wxEVT_DATAVIEW_ITEM_CONTEXT_MENU = 0
wxEVT_DATAVIEW_ITEM_DROP = 0
wxEVT_DATAVIEW_ITEM_DROP_POSSIBLE = 0
wxEVT_DATAVIEW_ITEM_EDITING_DONE = 0
wxEVT_DATAVIEW_ITEM_EDITING_STARTED = 0
wxEVT_DATAVIEW_ITEM_EXPANDED = 0
wxEVT_DATAVIEW_ITEM_EXPANDING = 0
wxEVT_DATAVIEW_ITEM_START_EDITING = 0
wxEVT_DATAVIEW_ITEM_VALUE_CHANGED = 0
wxEVT_DATAVIEW_SELECTION_CHANGED = 0
wxEVT_TREELIST_COLUMN_SORTED = 0
wxEVT_TREELIST_ITEM_ACTIVATED = 0
wxEVT_TREELIST_ITEM_CHECKED = 0
wxEVT_TREELIST_ITEM_CONTEXT_MENU = 0
wxEVT_TREELIST_ITEM_EXPANDED = 0
wxEVT_TREELIST_ITEM_EXPANDING = 0
wxEVT_TREELIST_SELECTION_CHANGED = 0



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


CheckListCtrlMixin = object
EventChooser = object
EventLog = object
EventWatcher = object
OTHER_WIDTH = 0
_buildModuleEventMap = dummy_function
_eventBinders = None
_eventIdMap = None
_makeAttribString = dummy_function
_makeSourceString = dummy_function
_noWatchList = []
addModuleEvents = dummy_function
buildWxEventMap = dummy_function
cmp = dummy_function



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


grayOut = dummy_function
makeGray = dummy_function
stepColour = dummy_function



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


ColDragWindow = object
EVT_GRID_COL_MOVE = object
EVT_GRID_ROW_MOVE = object
GridColMoveEvent = object
GridColMover = object
GridRowMoveEvent = object
GridRowMover = object
RowDragWindow = object
_ColToRect = dummy_function
_RowToRect = dummy_function
wxEVT_COMMAND_GRID_COL_MOVE = 0
wxEVT_COMMAND_GRID_ROW_MOVE = 0



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


ColourSelect = object
ColourSelectEvent = object
CustomColourData = object
EVT_COLOURSELECT = object
wxEVT_COMMAND_COLOURSELECT = 0



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


Animation = object
EmptyXmlResource = dummy_function
ID_NONE = object
XRCCTRL = dummy_function
XRCID = dummy_function
XRC_NO_RELOADING = object
XRC_NO_SUBCLASSING = object
XRC_USE_LOCALE = object
XmlResource = object
XmlResourceFlags = object
XmlResourceHandler = object
XmlSubclassFactory = object
XmlSubclassFactory_Python = object
_my_import = dummy_function



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


MultiMessageBox = dummy_function
SOT = 0
SoftwareUpdate = object
URLError = object
UpdateAbortedError = object
urlopen = dummy_function



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


EVT_HTML_CELL_CLICKED = object
EVT_HTML_CELL_HOVER = object
EVT_HTML_LINK_CLICKED = object
HF_BOOKMARKS = 0
HF_CONTENTS = 0
HF_DEFAULT_STYLE = 0
HF_DIALOG = 0
HF_EMBEDDED = 0
HF_FLAT_TOOLBAR = 0
HF_FRAME = 0
HF_ICONS_BOOK = 0
HF_ICONS_BOOK_CHAPTER = 0
HF_ICONS_FOLDER = 0
HF_INDEX = 0
HF_MERGE_BOOKS = 0
HF_MODAL = 0
HF_OPEN_FILES = 0
HF_PRINT = 0
HF_SEARCH = 0
HF_TOOLBAR = 0
HLB_DEFAULT_STYLE = 0
HLB_MULTIPLE = 0
HTML_ALIGN_BOTTOM = 0
HTML_ALIGN_CENTER = 0
HTML_ALIGN_JUSTIFY = 0
HTML_ALIGN_LEFT = 0
HTML_ALIGN_RIGHT = 0
HTML_ALIGN_TOP = 0
HTML_BLOCK = object
HTML_CLR_BACKGROUND = 0
HTML_CLR_FOREGROUND = 0
HTML_CLR_TRANSPARENT_BACKGROUND = 0
HTML_COND_ISANCHOR = 0
HTML_COND_ISIMAGEMAP = 0
HTML_COND_USER = 0
HTML_FIND_EXACT = 0
HTML_FIND_NEAREST_AFTER = 0
HTML_FIND_NEAREST_BEFORE = 0
HTML_INDENT_ALL = 0
HTML_INDENT_BOTTOM = 0
HTML_INDENT_HORIZONTAL = 0
HTML_INDENT_LEFT = 0
HTML_INDENT_RIGHT = 0
HTML_INDENT_TOP = 0
HTML_INDENT_VERTICAL = 0
HTML_OPEN = object
HTML_REDIRECT = object
HTML_SCRIPT_NORMAL = object
HTML_SCRIPT_SUB = object
HTML_SCRIPT_SUP = object
HTML_SEL_CHANGING = object
HTML_SEL_IN = object
HTML_SEL_OUT = object
HTML_UNITS_PERCENT = 0
HTML_UNITS_PIXELS = 0
HTML_URL_IMAGE = object
HTML_URL_OTHER = object
HTML_URL_PAGE = object
HW_DEFAULT_STYLE = 0
HW_NO_SELECTION = 0
HW_SCROLLBAR_AUTO = 0
HW_SCROLLBAR_NEVER = 0
HtmlBookRecArray = object
HtmlBookRecord = object
HtmlCell = object
HtmlCellEvent = object
HtmlColourCell = object
HtmlContainerCell = object
HtmlDCRenderer = object
HtmlEasyPrinting = object
HtmlFilter = object
HtmlFontCell = object
HtmlHelpController = object
HtmlHelpData = object
HtmlHelpDataItem = object
HtmlHelpDataItems = object
HtmlHelpDialog = object
HtmlHelpFrame = object
HtmlHelpWindow = object
HtmlLinkEvent = object
HtmlLinkInfo = object
HtmlListBox = object
HtmlListBoxNameStr = bytes()
HtmlModalHelp = object
HtmlOpeningStatus = object
HtmlParser = object
HtmlPrintout = object
HtmlRenderingInfo = object
HtmlRenderingState = object
HtmlRenderingStyle = object
HtmlScriptMode = object
HtmlSelection = object
HtmlSelectionState = object
HtmlTag = object
HtmlTagHandler = object
HtmlURLType = object
HtmlWidgetCell = object
HtmlWinParser = object
HtmlWinParser_AddTagHandler = dummy_function
HtmlWinTagHandler = object
HtmlWindow = object
HtmlWindowInterface = object
HtmlWordCell = object
HtmlWordWithTabsCell = object
ID_HTML_BACK = 0
ID_HTML_BOOKMARKSADD = 0
ID_HTML_BOOKMARKSLIST = 0
ID_HTML_BOOKMARKSREMOVE = 0
ID_HTML_COUNTINFO = 0
ID_HTML_DOWN = 0
ID_HTML_FORWARD = 0
ID_HTML_HELPFRAME = 0
ID_HTML_INDEXBUTTON = 0
ID_HTML_INDEXBUTTONALL = 0
ID_HTML_INDEXLIST = 0
ID_HTML_INDEXPAGE = 0
ID_HTML_INDEXTEXT = 0
ID_HTML_NOTEBOOK = 0
ID_HTML_OPENFILE = 0
ID_HTML_OPTIONS = 0
ID_HTML_PANEL = 0
ID_HTML_PRINT = 0
ID_HTML_SEARCHBUTTON = 0
ID_HTML_SEARCHCHOICE = 0
ID_HTML_SEARCHLIST = 0
ID_HTML_SEARCHPAGE = 0
ID_HTML_SEARCHTEXT = 0
ID_HTML_TREECTRL = 0
ID_HTML_UP = 0
ID_HTML_UPNODE = 0
INT_MAX = 0
PAGE_ALL = 0
PAGE_EVEN = 0
PAGE_ODD = 0
SimpleHtmlListBox = object
SimpleHtmlListBoxNameStr = bytes()
wxEVT_COMMAND_HTML_CELL_CLICKED = 0
wxEVT_COMMAND_HTML_CELL_HOVER = 0
wxEVT_COMMAND_HTML_LINK_CLICKED = 0
wxEVT_HTML_CELL_CLICKED = 0
wxEVT_HTML_CELL_HOVER = 0
wxEVT_HTML_LINK_CLICKED = 0



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


XMLDOC_KEEP_WHITESPACE_NODES = object
XMLDOC_NONE = object
XML_ATTRIBUTE_NODE = object
XML_CDATA_SECTION_NODE = object
XML_COMMENT_NODE = object
XML_DOCUMENT_FRAG_NODE = object
XML_DOCUMENT_NODE = object
XML_DOCUMENT_TYPE_NODE = object
XML_ELEMENT_NODE = object
XML_ENTITY_NODE = object
XML_ENTITY_REF_NODE = object
XML_HTML_DOCUMENT_NODE = object
XML_NOTATION_NODE = object
XML_NO_INDENTATION = 0
XML_PI_NODE = object
XML_TEXT_NODE = object
XmlAttribute = object
XmlDocument = object
XmlDocumentLoadFlag = object
XmlNode = object
XmlNodeType = object
XmlProperty = object



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


AbrWeekday = dict()
BusCalDays = []
COLOR_3D_DARK = ''
COLOR_3D_LIGHT = ''
COLOR_BACKGROUND = ''
COLOR_BORDER = ''
COLOR_FONT = ''
COLOR_GRID_LINES = ''
COLOR_HEADER_BACKGROUND = ''
COLOR_HEADER_FONT = ''
COLOR_HIGHLIGHT_BACKGROUND = ''
COLOR_HIGHLIGHT_FONT = ''
COLOR_SELECTION_BACKGROUND = ''
COLOR_SELECTION_FONT = ''
COLOR_WEEKEND_BACKGROUND = ''
COLOR_WEEKEND_FONT = ''
CalDays = []
CalDraw = object
CalenDlg = object
Calendar = object
DefaultColors = dummy_function
EVT_CALENDAR = object
GetMonthList = dummy_function
MakeColor = dummy_function
Month = dict()
PrtCalDraw = object
_ = dummy_function
_MIDSIZE = 0
wxEVT_COMMAND_PYCALENDAR_DAY_CLICKED = 0



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


EVT_RIBBONBAR_HELP_CLICK = object
EVT_RIBBONBAR_PAGE_CHANGED = object
EVT_RIBBONBAR_PAGE_CHANGING = object
EVT_RIBBONBAR_TAB_LEFT_DCLICK = object
EVT_RIBBONBAR_TAB_MIDDLE_DOWN = object
EVT_RIBBONBAR_TAB_MIDDLE_UP = object
EVT_RIBBONBAR_TAB_RIGHT_DOWN = object
EVT_RIBBONBAR_TAB_RIGHT_UP = object
EVT_RIBBONBAR_TOGGLED = object
EVT_RIBBONBUTTONBAR_CLICKED = object
EVT_RIBBONBUTTONBAR_DROPDOWN_CLICKED = object
EVT_RIBBONGALLERY_CLICKED = object
EVT_RIBBONGALLERY_HOVER_CHANGED = object
EVT_RIBBONGALLERY_SELECTED = object
EVT_RIBBONPANEL_EXTBUTTON_ACTIVATED = object
EVT_RIBBONTOOLBAR_CLICKED = object
EVT_RIBBONTOOLBAR_DROPDOWN_CLICKED = object
RIBBON_ART_BUTTON_BAR_ACTIVE_BACKGROUND_COLOUR = object
RIBBON_ART_BUTTON_BAR_ACTIVE_BACKGROUND_GRADIENT_COLOUR = object
RIBBON_ART_BUTTON_BAR_ACTIVE_BACKGROUND_TOP_COLOUR = object
RIBBON_ART_BUTTON_BAR_ACTIVE_BACKGROUND_TOP_GRADIENT_COLOUR = object
RIBBON_ART_BUTTON_BAR_ACTIVE_BORDER_COLOUR = object
RIBBON_ART_BUTTON_BAR_HOVER_BACKGROUND_COLOUR = object
RIBBON_ART_BUTTON_BAR_HOVER_BACKGROUND_GRADIENT_COLOUR = object
RIBBON_ART_BUTTON_BAR_HOVER_BACKGROUND_TOP_COLOUR = object
RIBBON_ART_BUTTON_BAR_HOVER_BACKGROUND_TOP_GRADIENT_COLOUR = object
RIBBON_ART_BUTTON_BAR_HOVER_BORDER_COLOUR = object
RIBBON_ART_BUTTON_BAR_LABEL_COLOUR = object
RIBBON_ART_BUTTON_BAR_LABEL_DISABLED_COLOUR = object
RIBBON_ART_BUTTON_BAR_LABEL_FONT = object
RIBBON_ART_GALLERY_BITMAP_PADDING_BOTTOM_SIZE = object
RIBBON_ART_GALLERY_BITMAP_PADDING_LEFT_SIZE = object
RIBBON_ART_GALLERY_BITMAP_PADDING_RIGHT_SIZE = object
RIBBON_ART_GALLERY_BITMAP_PADDING_TOP_SIZE = object
RIBBON_ART_GALLERY_BORDER_COLOUR = object
RIBBON_ART_GALLERY_BUTTON_ACTIVE_BACKGROUND_COLOUR = object
RIBBON_ART_GALLERY_BUTTON_ACTIVE_BACKGROUND_GRADIENT_COLOUR = object
RIBBON_ART_GALLERY_BUTTON_ACTIVE_BACKGROUND_TOP_COLOUR = object
RIBBON_ART_GALLERY_BUTTON_ACTIVE_FACE_COLOUR = object
RIBBON_ART_GALLERY_BUTTON_BACKGROUND_COLOUR = object
RIBBON_ART_GALLERY_BUTTON_BACKGROUND_GRADIENT_COLOUR = object
RIBBON_ART_GALLERY_BUTTON_BACKGROUND_TOP_COLOUR = object
RIBBON_ART_GALLERY_BUTTON_DISABLED_BACKGROUND_COLOUR = object
RIBBON_ART_GALLERY_BUTTON_DISABLED_BACKGROUND_GRADIENT_COLOUR = object
RIBBON_ART_GALLERY_BUTTON_DISABLED_BACKGROUND_TOP_COLOUR = object
RIBBON_ART_GALLERY_BUTTON_DISABLED_FACE_COLOUR = object
RIBBON_ART_GALLERY_BUTTON_FACE_COLOUR = object
RIBBON_ART_GALLERY_BUTTON_HOVER_BACKGROUND_COLOUR = object
RIBBON_ART_GALLERY_BUTTON_HOVER_BACKGROUND_GRADIENT_COLOUR = object
RIBBON_ART_GALLERY_BUTTON_HOVER_BACKGROUND_TOP_COLOUR = object
RIBBON_ART_GALLERY_BUTTON_HOVER_FACE_COLOUR = object
RIBBON_ART_GALLERY_HOVER_BACKGROUND_COLOUR = object
RIBBON_ART_GALLERY_ITEM_BORDER_COLOUR = object
RIBBON_ART_PAGE_BACKGROUND_COLOUR = object
RIBBON_ART_PAGE_BACKGROUND_GRADIENT_COLOUR = object
RIBBON_ART_PAGE_BACKGROUND_TOP_COLOUR = object
RIBBON_ART_PAGE_BACKGROUND_TOP_GRADIENT_COLOUR = object
RIBBON_ART_PAGE_BORDER_BOTTOM_SIZE = object
RIBBON_ART_PAGE_BORDER_COLOUR = object
RIBBON_ART_PAGE_BORDER_LEFT_SIZE = object
RIBBON_ART_PAGE_BORDER_RIGHT_SIZE = object
RIBBON_ART_PAGE_BORDER_TOP_SIZE = object
RIBBON_ART_PAGE_HOVER_BACKGROUND_COLOUR = object
RIBBON_ART_PAGE_HOVER_BACKGROUND_GRADIENT_COLOUR = object
RIBBON_ART_PAGE_HOVER_BACKGROUND_TOP_COLOUR = object
RIBBON_ART_PAGE_HOVER_BACKGROUND_TOP_GRADIENT_COLOUR = object
RIBBON_ART_PANEL_ACTIVE_BACKGROUND_COLOUR = object
RIBBON_ART_PANEL_ACTIVE_BACKGROUND_GRADIENT_COLOUR = object
RIBBON_ART_PANEL_ACTIVE_BACKGROUND_TOP_COLOUR = object
RIBBON_ART_PANEL_ACTIVE_BACKGROUND_TOP_GRADIENT_COLOUR = object
RIBBON_ART_PANEL_BORDER_COLOUR = object
RIBBON_ART_PANEL_BORDER_GRADIENT_COLOUR = object
RIBBON_ART_PANEL_HOVER_LABEL_BACKGROUND_COLOUR = object
RIBBON_ART_PANEL_HOVER_LABEL_BACKGROUND_GRADIENT_COLOUR = object
RIBBON_ART_PANEL_HOVER_LABEL_COLOUR = object
RIBBON_ART_PANEL_LABEL_BACKGROUND_COLOUR = object
RIBBON_ART_PANEL_LABEL_BACKGROUND_GRADIENT_COLOUR = object
RIBBON_ART_PANEL_LABEL_COLOUR = object
RIBBON_ART_PANEL_LABEL_FONT = object
RIBBON_ART_PANEL_MINIMISED_BORDER_COLOUR = object
RIBBON_ART_PANEL_MINIMISED_BORDER_GRADIENT_COLOUR = object
RIBBON_ART_PANEL_MINIMISED_LABEL_COLOUR = object
RIBBON_ART_PANEL_X_SEPARATION_SIZE = object
RIBBON_ART_PANEL_Y_SEPARATION_SIZE = object
RIBBON_ART_TAB_ACTIVE_BACKGROUND_COLOUR = object
RIBBON_ART_TAB_ACTIVE_BACKGROUND_GRADIENT_COLOUR = object
RIBBON_ART_TAB_ACTIVE_BACKGROUND_TOP_COLOUR = object
RIBBON_ART_TAB_ACTIVE_BACKGROUND_TOP_GRADIENT_COLOUR = object
RIBBON_ART_TAB_BORDER_COLOUR = object
RIBBON_ART_TAB_CTRL_BACKGROUND_COLOUR = object
RIBBON_ART_TAB_CTRL_BACKGROUND_GRADIENT_COLOUR = object
RIBBON_ART_TAB_HOVER_BACKGROUND_COLOUR = object
RIBBON_ART_TAB_HOVER_BACKGROUND_GRADIENT_COLOUR = object
RIBBON_ART_TAB_HOVER_BACKGROUND_TOP_COLOUR = object
RIBBON_ART_TAB_HOVER_BACKGROUND_TOP_GRADIENT_COLOUR = object
RIBBON_ART_TAB_LABEL_COLOUR = object
RIBBON_ART_TAB_LABEL_FONT = object
RIBBON_ART_TAB_SEPARATION_SIZE = object
RIBBON_ART_TAB_SEPARATOR_COLOUR = object
RIBBON_ART_TAB_SEPARATOR_GRADIENT_COLOUR = object
RIBBON_ART_TOOLBAR_BORDER_COLOUR = object
RIBBON_ART_TOOLBAR_FACE_COLOUR = object
RIBBON_ART_TOOLBAR_HOVER_BORDER_COLOUR = object
RIBBON_ART_TOOL_ACTIVE_BACKGROUND_COLOUR = object
RIBBON_ART_TOOL_ACTIVE_BACKGROUND_GRADIENT_COLOUR = object
RIBBON_ART_TOOL_ACTIVE_BACKGROUND_TOP_COLOUR = object
RIBBON_ART_TOOL_ACTIVE_BACKGROUND_TOP_GRADIENT_COLOUR = object
RIBBON_ART_TOOL_BACKGROUND_COLOUR = object
RIBBON_ART_TOOL_BACKGROUND_GRADIENT_COLOUR = object
RIBBON_ART_TOOL_BACKGROUND_TOP_COLOUR = object
RIBBON_ART_TOOL_BACKGROUND_TOP_GRADIENT_COLOUR = object
RIBBON_ART_TOOL_GROUP_SEPARATION_SIZE = object
RIBBON_ART_TOOL_HOVER_BACKGROUND_COLOUR = object
RIBBON_ART_TOOL_HOVER_BACKGROUND_GRADIENT_COLOUR = object
RIBBON_ART_TOOL_HOVER_BACKGROUND_TOP_COLOUR = object
RIBBON_ART_TOOL_HOVER_BACKGROUND_TOP_GRADIENT_COLOUR = object
RIBBON_BAR_ALWAYS_SHOW_TABS = object
RIBBON_BAR_DEFAULT_STYLE = object
RIBBON_BAR_EXPANDED = object
RIBBON_BAR_FLOW_HORIZONTAL = object
RIBBON_BAR_FLOW_VERTICAL = object
RIBBON_BAR_FOLDBAR_STYLE = object
RIBBON_BAR_MINIMIZED = object
RIBBON_BAR_PINNED = object
RIBBON_BAR_SHOW_HELP_BUTTON = object
RIBBON_BAR_SHOW_PAGE_ICONS = object
RIBBON_BAR_SHOW_PAGE_LABELS = object
RIBBON_BAR_SHOW_PANEL_EXT_BUTTONS = object
RIBBON_BAR_SHOW_PANEL_MINIMISE_BUTTONS = object
RIBBON_BAR_SHOW_TOGGLE_BUTTON = object
RIBBON_BUTTONBAR_BUTTON_ACTIVE_MASK = object
RIBBON_BUTTONBAR_BUTTON_DISABLED = object
RIBBON_BUTTONBAR_BUTTON_DROPDOWN_ACTIVE = object
RIBBON_BUTTONBAR_BUTTON_DROPDOWN_HOVERED = object
RIBBON_BUTTONBAR_BUTTON_HOVER_MASK = object
RIBBON_BUTTONBAR_BUTTON_LARGE = object
RIBBON_BUTTONBAR_BUTTON_MEDIUM = object
RIBBON_BUTTONBAR_BUTTON_NORMAL_ACTIVE = object
RIBBON_BUTTONBAR_BUTTON_NORMAL_HOVERED = object
RIBBON_BUTTONBAR_BUTTON_SIZE_MASK = object
RIBBON_BUTTONBAR_BUTTON_SMALL = object
RIBBON_BUTTONBAR_BUTTON_STATE_MASK = object
RIBBON_BUTTONBAR_BUTTON_TOGGLED = object
RIBBON_BUTTON_DROPDOWN = object
RIBBON_BUTTON_HYBRID = object
RIBBON_BUTTON_NORMAL = object
RIBBON_BUTTON_TOGGLE = object
RIBBON_GALLERY_BUTTON_ACTIVE = object
RIBBON_GALLERY_BUTTON_DISABLED = object
RIBBON_GALLERY_BUTTON_HOVERED = object
RIBBON_GALLERY_BUTTON_NORMAL = object
RIBBON_PANEL_DEFAULT_STYLE = object
RIBBON_PANEL_EXT_BUTTON = object
RIBBON_PANEL_FLEXIBLE = object
RIBBON_PANEL_MINIMISE_BUTTON = object
RIBBON_PANEL_NO_AUTO_MINIMISE = object
RIBBON_PANEL_STRETCH = object
RIBBON_SCROLL_BTN_ACTIVE = object
RIBBON_SCROLL_BTN_DIRECTION_MASK = object
RIBBON_SCROLL_BTN_DOWN = object
RIBBON_SCROLL_BTN_FOR_MASK = object
RIBBON_SCROLL_BTN_FOR_OTHER = object
RIBBON_SCROLL_BTN_FOR_PAGE = object
RIBBON_SCROLL_BTN_FOR_TABS = object
RIBBON_SCROLL_BTN_HOVERED = object
RIBBON_SCROLL_BTN_LEFT = object
RIBBON_SCROLL_BTN_NORMAL = object
RIBBON_SCROLL_BTN_RIGHT = object
RIBBON_SCROLL_BTN_STATE_MASK = object
RIBBON_SCROLL_BTN_UP = object
RibbonAUIArtProvider = object
RibbonArtProvider = object
RibbonArtSetting = object
RibbonBar = object
RibbonBarEvent = object
RibbonBarOption = object
RibbonButtonBar = object
RibbonButtonBarButtonBase = object
RibbonButtonBarButtonState = object
RibbonButtonBarEvent = object
RibbonButtonKind = object
RibbonControl = object
RibbonDefaultArtProvider = object
RibbonDisplayMode = object
RibbonGallery = object
RibbonGalleryButtonState = object
RibbonGalleryEvent = object
RibbonGalleryItem = object
RibbonMSWArtProvider = object
RibbonPage = object
RibbonPageTabInfo = object
RibbonPageTabInfoArray = object
RibbonPanel = object
RibbonPanelEvent = object
RibbonPanelOption = object
RibbonScrollButtonStyle = object
RibbonToolBar = object
RibbonToolBarEvent = object
RibbonToolBarToolBase = object
wxEVT_RIBBONBAR_HELP_CLICK = 0
wxEVT_RIBBONBAR_PAGE_CHANGED = 0
wxEVT_RIBBONBAR_PAGE_CHANGING = 0
wxEVT_RIBBONBAR_TAB_LEFT_DCLICK = 0
wxEVT_RIBBONBAR_TAB_MIDDLE_DOWN = 0
wxEVT_RIBBONBAR_TAB_MIDDLE_UP = 0
wxEVT_RIBBONBAR_TAB_RIGHT_DOWN = 0
wxEVT_RIBBONBAR_TAB_RIGHT_UP = 0
wxEVT_RIBBONBAR_TOGGLED = 0
wxEVT_RIBBONBUTTONBAR_CLICKED = 0
wxEVT_RIBBONBUTTONBAR_DROPDOWN_CLICKED = 0
wxEVT_RIBBONGALLERY_CLICKED = 0
wxEVT_RIBBONGALLERY_HOVER_CHANGED = 0
wxEVT_RIBBONGALLERY_SELECTED = 0
wxEVT_RIBBONPANEL_EXTBUTTON_ACTIVATED = 0
wxEVT_RIBBONTOOLBAR_CLICKED = 0
wxEVT_RIBBONTOOLBAR_DROPDOWN_CLICKED = 0



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


AdjustAlpha = dummy_function
AdjustColour = dummy_function
BestLabelColour = dummy_function
EVT_PLATEBTN_DROPARROW_PRESSED = object
GetHighlightColour = dummy_function
PB_STYLE_DEFAULT = 0
PB_STYLE_DROPARROW = 0
PB_STYLE_GRADIENT = 0
PB_STYLE_NOBG = 0
PB_STYLE_SQUARE = 0
PB_STYLE_TOGGLE = 0
PLATE_HIGHLIGHT = 0
PLATE_NORMAL = 0
PLATE_PRESSED = 0
PlateBtnDropArrowPressed = object
PlateButton = object



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


EventAdapter = object
EventMacroInfo = object
EventManager = object
FakeWindow = object
MessageAdapter = object
_macroInfo = object
eventManager = object



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


AEDIALOG_STYLE = 0
ArrayPGProperty = object
ArrayStringProperty = object
BoolProperty = object
ColourProperty = object
ColourPropertyValue = object
CursorProperty = object
DateProperty = object
DirProperty = object
EVT_PG_CHANGED = object
EVT_PG_CHANGING = object
EVT_PG_COL_BEGIN_DRAG = object
EVT_PG_COL_DRAGGING = object
EVT_PG_COL_END_DRAG = object
EVT_PG_DOUBLE_CLICK = object
EVT_PG_HIGHLIGHTED = object
EVT_PG_ITEM_COLLAPSED = object
EVT_PG_ITEM_EXPANDED = object
EVT_PG_LABEL_EDIT_BEGIN = object
EVT_PG_LABEL_EDIT_ENDING = object
EVT_PG_PAGE_CHANGED = object
EVT_PG_RIGHT_CLICK = object
EVT_PG_SELECTED = object
EditEnumProperty = object
EnumProperty = object
FileProperty = object
FlagsProperty = object
FloatProperty = object
FontProperty = object
ImageFileProperty = object
IntProperty = object
LongStringProperty = object
MultiChoiceProperty = object
NullProperty = None
NumericPropertyValidator = object
PGArrayEditorDialog = object
PGArrayStringEditorDialog = object
PGCell = object
PGCellData = object
PGCellRenderer = object
PGCheckBoxEditor = object
PGChoiceAndButtonEditor = object
PGChoiceEditor = object
PGChoiceEntry = object
PGChoices = object
PGChoicesData = object
PGChoicesEmptyData = None
PGComboBoxEditor = object
PGDefaultRenderer = object
PGEditor = object
PGEditorDialogAdapter = object
PGEditor_CheckBox = object
PGEditor_Choice = object
PGEditor_ChoiceAndButton = object
PGEditor_ComboBox = object
PGEditor_DatePickerCtrl = object
PGEditor_SpinCtrl = object
PGEditor_TextCtrl = object
PGEditor_TextCtrlAndButton = object
PGFileDialogAdapter = object
PGGetDefaultImageWildcard = dummy_function
PGInDialogValidator = object
PGLongStringDialogAdapter = object
PGMAN_DEFAULT_STYLE = 0
PGMultiButton = object
PGNumericValidationConstants = object
PGPaintData = object
PGPropArgCls = object
PGProperty = object
PGPropertyFlags = object
PGSpinCtrlEditor = object
PGTextCtrlAndButtonEditor = object
PGTextCtrlEditor = object
PGVIterator = object
PGValidationInfo = object
PGWindowList = object
PG_ACTION_CANCEL_EDIT = object
PG_ACTION_COLLAPSE_PROPERTY = object
PG_ACTION_EDIT = object
PG_ACTION_EXPAND_PROPERTY = object
PG_ACTION_INVALID = object
PG_ACTION_MAX = object
PG_ACTION_NEXT_PROPERTY = object
PG_ACTION_PRESS_BUTTON = object
PG_ACTION_PREV_PROPERTY = object
PG_ALPHABETIC_MODE = object
PG_ARRAY_DELIMITER = ''
PG_ATTR_AUTOCOMPLETE = ''
PG_ATTR_DEFAULT_VALUE = ''
PG_ATTR_HINT = ''
PG_ATTR_INLINE_HELP = ''
PG_ATTR_MAX = ''
PG_ATTR_MIN = ''
PG_ATTR_MULTICHOICE_USERSTRINGMODE = ''
PG_ATTR_SPINCTRL_MOTIONSPIN = ''
PG_ATTR_SPINCTRL_STEP = ''
PG_ATTR_SPINCTRL_WRAP = ''
PG_ATTR_UNITS = ''
PG_AUTO_SORT = object
PG_BASE_DEC = 0
PG_BASE_HEX = 0
PG_BASE_HEXL = 0
PG_BASE_OCT = 0
PG_BOLD_MODIFIED = object
PG_BOOL_USE_CHECKBOX = ''
PG_BOOL_USE_DOUBLE_CLICK_CYCLING = ''
PG_CAPRECTXMARGIN = 0
PG_CAPRECTYMARGIN = 0
PG_COLOUR_ALLOW_CUSTOM = ''
PG_COLOUR_BLACK = object
PG_COLOUR_CUSTOM = 0
PG_COLOUR_HAS_ALPHA = ''
PG_COLOUR_UNSPECIFIED = 0
PG_COLOUR_WEB_BASE = 0
PG_COMPOSITE_FRAGMENT = object
PG_CUSTOM_IMAGE_SPACINGY = 0
PG_DATE_FORMAT = ''
PG_DATE_PICKER_STYLE = ''
PG_DEFAULT_IMAGE_SIZE = object
PG_DEFAULT_STYLE = 0
PG_DESCRIPTION = object
PG_DIR_DIALOG_MESSAGE = ''
PG_DONT_RECURSE = 0
PG_EDITABLE_VALUE = object
PG_EX_AUTO_UNSPECIFIED_VALUES = object
PG_EX_ENABLE_TLP_TRACKING = object
PG_EX_HELP_AS_TOOLTIPS = object
PG_EX_HIDE_PAGE_BUTTONS = object
PG_EX_INIT_NOCAT = object
PG_EX_MODE_BUTTONS = object
PG_EX_MULTIPLE_SELECTION = object
PG_EX_NATIVE_DOUBLE_BUFFERING = object
PG_EX_NO_FLAT_TOOLBAR = object
PG_EX_NO_TOOLBAR_DIVIDER = object
PG_EX_TOOLBAR_SEPARATOR = object
PG_EX_WINDOW_STYLES = object
PG_EX_WRITEONLY_BUILTIN_ATTRIBUTES = object
PG_FILE_DIALOG_STYLE = ''
PG_FILE_DIALOG_TITLE = ''
PG_FILE_INITIAL_PATH = ''
PG_FILE_SHOW_FULL_PATH = ''
PG_FILE_SHOW_RELATIVE_PATH = ''
PG_FILE_WILDCARD = ''
PG_FLOAT_PRECISION = ''
PG_FORCE = object
PG_FULL_VALUE = object
PG_GETPROPERTYVALUES_FLAGS = object
PG_HIDE_CATEGORIES = object
PG_HIDE_MARGIN = object
PG_INC_ATTRIBUTES = object
PG_INVALID_VALUE = 0
PG_ITERATE_ALL = object
PG_ITERATE_ALL_PARENTS = object
PG_ITERATE_ALL_PARENTS_RECURSIVELY = object
PG_ITERATE_CATEGORIES = object
PG_ITERATE_DEFAULT = object
PG_ITERATE_FIXED_CHILDREN = object
PG_ITERATE_HIDDEN = object
PG_ITERATE_NORMAL = object
PG_ITERATE_PROPERTIES = object
PG_ITERATE_VISIBLE = object
PG_ITERATOR_FLAGS = object
PG_ITERATOR_FLAGS_ALL = object
PG_ITERATOR_MASK_OP_ITEM = object
PG_ITERATOR_MASK_OP_PARENT = object
PG_KEEP_STRUCTURE = object
PG_KEYBOARD_ACTIONS = object
PG_LABEL = ''
PG_LABEL_STRING = ''
PG_LIMITED_EDITING = object
PG_MISC_ARG_FLAGS = object
PG_NO_INTERNAL_BORDER = object
PG_NULL_BITMAP = object
PG_PREFIX_0x = 0
PG_PREFIX_DOLLAR_SIGN = 0
PG_PREFIX_NONE = 0
PG_PROGRAMMATIC_VALUE = object
PG_PROPERTY_SPECIFIC = object
PG_PROPERTY_VALIDATION_ERROR_MESSAGE = object
PG_PROPERTY_VALIDATION_SATURATE = object
PG_PROPERTY_VALIDATION_WRAP = object
PG_PROP_AGGREGATE = object
PG_PROP_AUTO_UNSPECIFIED = object
PG_PROP_BEING_DELETED = object
PG_PROP_CATEGORY = object
PG_PROP_CHILDREN_ARE_COPIES = object
PG_PROP_CLASS_SPECIFIC_1 = object
PG_PROP_CLASS_SPECIFIC_2 = object
PG_PROP_COLLAPSED = object
PG_PROP_COMPOSED_VALUE = object
PG_PROP_CUSTOMIMAGE = object
PG_PROP_DISABLED = object
PG_PROP_HIDDEN = object
PG_PROP_INVALID_VALUE = object
PG_PROP_MAX = 0
PG_PROP_MISC_PARENT = object
PG_PROP_MODIFIED = object
PG_PROP_NOEDITOR = object
PG_PROP_NO_ESCAPE = 0
PG_PROP_PARENTAL_FLAGS = 0
PG_PROP_PASSWORD = 0
PG_PROP_PROPERTY = object
PG_PROP_READONLY = object
PG_PROP_SHOW_FULL_FILENAME = 0
PG_PROP_STATIC_CHOICES = 0
PG_PROP_TRANSLATE_CUSTOM = 0
PG_PROP_USES_COMMON_VALUE = object
PG_PROP_USE_CHECKBOX = 0
PG_PROP_USE_DCC = 0
PG_PROP_WAS_MODIFIED = object
PG_RECURSE = object
PG_RECURSE_STARTS = object
PG_REPORT_ERROR = object
PG_SETVALUE_FLAGS = object
PG_SETVAL_AGGREGATED = object
PG_SETVAL_BY_USER = object
PG_SETVAL_FROM_PARENT = object
PG_SETVAL_REFRESH_EDITOR = object
PG_SORT_TOP_LEVEL_ONLY = object
PG_SPLITTER_AUTO_CENTER = object
PG_STATIC_LAYOUT = object
PG_STATIC_SPLITTER = object
PG_STRING_PASSWORD = ''
PG_SUBID1 = 0
PG_SUBID2 = 0
PG_SUBID_TEMP1 = 0
PG_TOOLBAR = object
PG_TOOLTIPS = object
PG_UINT_BASE = ''
PG_UINT_PREFIX = ''
PG_UNEDITABLE_COMPOSITE_FRAGMENT = object
PG_VALIDATION_FAILURE_BEHAVIOR_FLAGS = object
PG_VALUE_IS_CURRENT = object
PG_VFB_BEEP = object
PG_VFB_DEFAULT = object
PG_VFB_MARK_CELL = object
PG_VFB_SHOW_MESSAGE = object
PG_VFB_SHOW_MESSAGEBOX = object
PG_VFB_SHOW_MESSAGE_ON_STATUSBAR = object
PG_VFB_STAY_IN_PROPERTY = object
PG_WINDOW_STYLES = object
PropertyCategory = object
PropertyGrid = object
PropertyGridEvent = object
PropertyGridHitTestResult = object
PropertyGridInterface = object
PropertyGridIterator = object
PropertyGridIteratorBase = object
PropertyGridManager = object
PropertyGridManagerNameStr = bytes()
PropertyGridNameStr = bytes()
PropertyGridPage = object
PropertyGridPageState = object
PyArrayStringProperty = object
PyChoiceEditor = object
PyColourProperty = object
PyComboBoxEditor = object
PyEditEnumProperty = object
PyEditor = object
PyEditorDialogAdapter = object
PyEnumProperty = object
PyFileDialogAdapter = object
PyFileProperty = object
PyFlagsProperty = object
PyFloatProperty = object
PyFontProperty = object
PyIntProperty = object
PyLongStringDialogAdapter = object
PyLongStringProperty = object
PyProperty = object
PyStringProperty = object
PySystemColourProperty = object
PyTextCtrlEditor = object
PyUIntProperty = object
RegisterEditor = dummy_function
StringProperty = object
SystemColourProperty = object
UIntProperty = object
_PropertyGridManager__init__ = dummy_function
_PropertyGrid__init__ = dummy_function
_type2property = None
_vt2getter = None
testPGVariantTypeName = dummy_function
testPGVariantTypemap = dummy_function
wxEVT_PG_CHANGED = 0
wxEVT_PG_CHANGING = 0
wxEVT_PG_COL_BEGIN_DRAG = 0
wxEVT_PG_COL_DRAGGING = 0
wxEVT_PG_COL_END_DRAG = 0
wxEVT_PG_DOUBLE_CLICK = 0
wxEVT_PG_HIGHLIGHTED = 0
wxEVT_PG_ITEM_COLLAPSED = 0
wxEVT_PG_ITEM_EXPANDED = 0
wxEVT_PG_LABEL_EDIT_BEGIN = 0
wxEVT_PG_LABEL_EDIT_ENDING = 0
wxEVT_PG_PAGE_CHANGED = 0
wxEVT_PG_RIGHT_CLICK = 0
wxEVT_PG_SELECTED = 0



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


CollapseTree = object
EvtWatcher = object
ExpandTree = object
Find = object
FlagsFormatter = object
HighlightItem = object
Icon = object
InspectionFrame = object
InspectionInfoPanel = object
InspectionTool = object
InspectionTree = object
PyEmbeddedImage = object
Refresh = object
ShowFilling = object
ShowSizers = object
TreeBaseClass = object
_InspectionHighlighter = object
flexmodeFlags = dict()
itemFlags = dict()
orientFlags = dict()



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


MultiSplitterEvent = object
MultiSplitterWindow = object
_RENDER_VER = tuple()



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


EVT_GRID_CELL_BEGIN_DRAG = object
EVT_GRID_CELL_CHANGED = object
EVT_GRID_CELL_CHANGING = object
EVT_GRID_CELL_LEFT_CLICK = object
EVT_GRID_CELL_LEFT_DCLICK = object
EVT_GRID_CELL_RIGHT_CLICK = object
EVT_GRID_CELL_RIGHT_DCLICK = object
EVT_GRID_CMD_CELL_BEGIN_DRAG = object
EVT_GRID_CMD_CELL_CHANGED = object
EVT_GRID_CMD_CELL_CHANGING = object
EVT_GRID_CMD_CELL_LEFT_CLICK = object
EVT_GRID_CMD_CELL_LEFT_DCLICK = object
EVT_GRID_CMD_CELL_RIGHT_CLICK = object
EVT_GRID_CMD_CELL_RIGHT_DCLICK = object
EVT_GRID_CMD_COL_MOVE = object
EVT_GRID_CMD_COL_SIZE = object
EVT_GRID_CMD_COL_SORT = object
EVT_GRID_CMD_EDITOR_CREATED = object
EVT_GRID_CMD_EDITOR_HIDDEN = object
EVT_GRID_CMD_EDITOR_SHOWN = object
EVT_GRID_CMD_LABEL_LEFT_CLICK = object
EVT_GRID_CMD_LABEL_LEFT_DCLICK = object
EVT_GRID_CMD_LABEL_RIGHT_CLICK = object
EVT_GRID_CMD_LABEL_RIGHT_DCLICK = object
EVT_GRID_CMD_RANGE_SELECT = object
EVT_GRID_CMD_ROW_SIZE = object
EVT_GRID_CMD_SELECT_CELL = object
EVT_GRID_CMD_TABBING = object
EVT_GRID_COL_MOVE = object
EVT_GRID_COL_SIZE = object
EVT_GRID_COL_SORT = object
EVT_GRID_EDITOR_CREATED = object
EVT_GRID_EDITOR_HIDDEN = object
EVT_GRID_EDITOR_SHOWN = object
EVT_GRID_LABEL_LEFT_CLICK = object
EVT_GRID_LABEL_LEFT_DCLICK = object
EVT_GRID_LABEL_RIGHT_CLICK = object
EVT_GRID_LABEL_RIGHT_DCLICK = object
EVT_GRID_RANGE_SELECT = object
EVT_GRID_ROW_SIZE = object
EVT_GRID_SELECT_CELL = object
EVT_GRID_TABBING = object
GRIDTABLE_NOTIFY_COLS_APPENDED = object
GRIDTABLE_NOTIFY_COLS_DELETED = object
GRIDTABLE_NOTIFY_COLS_INSERTED = object
GRIDTABLE_NOTIFY_ROWS_APPENDED = object
GRIDTABLE_NOTIFY_ROWS_DELETED = object
GRIDTABLE_NOTIFY_ROWS_INSERTED = object
GRIDTABLE_REQUEST_VIEW_GET_VALUES = object
GRIDTABLE_REQUEST_VIEW_SEND_VALUES = object
GRID_AUTOSIZE = 0
GRID_COLUMN = object
GRID_DRAW_BOX_RECT = object
GRID_DRAW_CELL_LINES = object
GRID_DRAW_COLS_HEADER = object
GRID_DRAW_DEFAULT = object
GRID_DRAW_ROWS_HEADER = object
GRID_DRAW_SELECTION = object
GRID_FLOAT_FORMAT_COMPACT = object
GRID_FLOAT_FORMAT_DEFAULT = object
GRID_FLOAT_FORMAT_FIXED = object
GRID_FLOAT_FORMAT_SCIENTIFIC = object
GRID_FLOAT_FORMAT_UPPER = object
GRID_ROW = object
GRID_VALUE_BOOL = ''
GRID_VALUE_CHOICE = ''
GRID_VALUE_CHOICEINT = ''
GRID_VALUE_DATETIME = ''
GRID_VALUE_FLOAT = ''
GRID_VALUE_LONG = ''
GRID_VALUE_NUMBER = ''
GRID_VALUE_STRING = ''
GRID_VALUE_TEXT = ''
Grid = object
GridCellAttr = object
GridCellAttrProvider = object
GridCellAutoWrapStringEditor = object
GridCellAutoWrapStringRenderer = object
GridCellBoolEditor = object
GridCellBoolRenderer = object
GridCellChoiceEditor = object
GridCellCoords = object
GridCellCoordsArray = object
GridCellDateTimeRenderer = object
GridCellEditor = object
GridCellEnumEditor = object
GridCellEnumRenderer = object
GridCellFloatEditor = object
GridCellFloatFormat = object
GridCellFloatRenderer = object
GridCellNumberEditor = object
GridCellNumberRenderer = object
GridCellRenderer = object
GridCellStringRenderer = object
GridCellTextEditor = object
GridColumnHeaderRenderer = object
GridColumnHeaderRendererDefault = object
GridCornerHeaderRenderer = object
GridCornerHeaderRendererDefault = object
GridDirection = object
GridEditorCreatedEvent = object
GridEvent = object
GridHeaderLabelsRenderer = object
GridNameStr = bytes()
GridRangeSelectEvent = object
GridRenderStyle = object
GridRowHeaderRenderer = object
GridRowHeaderRendererDefault = object
GridSizeEvent = object
GridSizesInfo = object
GridStringTable = object
GridTableBase = object
GridTableMessage = object
GridTableRequest = object
GridUpdateLocker = object
PyGridCellAttrProvider = object
PyGridCellEditor = object
PyGridCellRenderer = object
PyGridTableBase = object
_im_GridCellCoords = object
wxEVT_GRID_CELL_BEGIN_DRAG = 0
wxEVT_GRID_CELL_CHANGED = 0
wxEVT_GRID_CELL_CHANGING = 0
wxEVT_GRID_CELL_LEFT_CLICK = 0
wxEVT_GRID_CELL_LEFT_DCLICK = 0
wxEVT_GRID_CELL_RIGHT_CLICK = 0
wxEVT_GRID_CELL_RIGHT_DCLICK = 0
wxEVT_GRID_COL_AUTO_SIZE = 0
wxEVT_GRID_COL_MOVE = 0
wxEVT_GRID_COL_SIZE = 0
wxEVT_GRID_COL_SORT = 0
wxEVT_GRID_EDITOR_CREATED = 0
wxEVT_GRID_EDITOR_HIDDEN = 0
wxEVT_GRID_EDITOR_SHOWN = 0
wxEVT_GRID_LABEL_LEFT_CLICK = 0
wxEVT_GRID_LABEL_LEFT_DCLICK = 0
wxEVT_GRID_LABEL_RIGHT_CLICK = 0
wxEVT_GRID_LABEL_RIGHT_DCLICK = 0
wxEVT_GRID_RANGE_SELECT = 0
wxEVT_GRID_ROW_SIZE = 0
wxEVT_GRID_SELECT_CELL = 0
wxEVT_GRID_TABBING = 0



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


EVT_RW_LAYOUT_NEEDED = object
RW_FILL = ''
RW_FILL2 = ''
RW_LENGTH = 0
RW_PEN = ''
RW_THICKNESS = 0
ResizeWidget = object
_RWLayoutNeededEvent = object



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


EVT_UPDATE_THROBBER = object
THROBBER_EVENT = 0
Throbber = object
UpdateThrobberEvent = object
